Learn R Programming

gppm (version 0.3.0)

vcov.GPPM: Variance-Covariance Matrix

Description

Returns the variance-covariance matrix of the parameters of a fitted GPPM.

Usage

# S3 method for GPPM
vcov(object, ...)

Value

A matrix of the estimated covariances between the parameter estimates. This has row and column names corresponding to the parameter names.

Arguments

object

object of class GPPM. Must be fitted, that is, a result from fit.GPPM.

...

additional arguments (currently not used).

See Also

Other functions to extract from a GPPM: SE(), coef.GPPM(), confint.GPPM(), covFun(), fitted.GPPM(), getData(), getIntern(), logLik.GPPM(), maxNObs(), meanFun(), nObs(), nPars(), nPers(), nPreds(), parEsts(), pars(), preds()

Examples

Run this code
# \donttest{
data("demoLGCM")
lgcm <- gppm(
  "muI+muS*t", "varI+covIS*(t+t#)+varS*t*t#+(t==t#)*sigma",
  demoLGCM, "ID", "y"
)
lgcmFit <- fit(lgcm)
covMat <- vcov(lgcmFit)
# }

Run the code above in your browser using DataLab